// Copyright (C) 2011-2013 - Michael Baudin
//
// This file must be used under the terms of the GNU Lesser General Public License license :
// http://www.gnu.org/copyleft/lesser.html

//
// <-- JVM NOT MANDATORY -->
// <-- ENGLISH IMPOSED -->

// Compute the first order sensitivity indices of the ishigami function.
// Three random variables uniform in [-pi,pi].
function y = ishigami (x)
    a=7.
    b=0.1
    s1=sin(x(:,1))
    s2=sin(x(:,2))
    x34 = x(:,3).^4
    y(:,1) = s1 + a.*s2.^2 + b.*x34.*s1
endfunction
function x = myrandgen ( m , i )
    x = distfun_unifrnd(-%pi,%pi,m,1)
endfunction
distfun_seedset(0);
a=7.;
b=0.1;
exact = nisp_ishigamisa ( a , b );
SE(1) = exact.S1;
SE(2) = exact.S2;
SE(3) = exact.S3;
//
//
n = 100000;
nx = 3;
[ s , nbevalf ] = nisp_sobolsaFirst ( ishigami , nx , myrandgen , n );
assert_checkalmostequal ( s, SE , 1.e-1 , 1.e-2 );
assert_checkequal ( nbevalf , 400000 );
//
// With default n
distfun_seedset(0);
[ s , nbevalf ] = nisp_sobolsaFirst ( ishigami , nx , myrandgen );
assert_checkalmostequal ( s, SE , 1.e-1 , 1.e-2 );
assert_checkequal ( nbevalf , 40000 );
//
// With default randgen
distfun_seedset(0);
function y = ishigami3 ( x )
    // From [0,1] to [-pi,pi]
    x = 2*%pi.*x - %pi
    a=7.
    b=0.1
    s1=sin(x(:,1))
    s2=sin(x(:,2))
    x34 = x(:,3).^4
    y(:,1) = s1 + a.*s2.^2 + b.*x34.*s1
endfunction
[ s , nbevalf ] = nisp_sobolsaFirst ( ishigami3 , nx );
assert_checkalmostequal ( s, SE , 1.e-1 , 1.e-2 );
assert_checkequal ( nbevalf , 40000 );
//
// With additionnal arguments for f.
function y = ishigami2 ( x , a , b )
    s1=sin(x(:,1))
    s2=sin(x(:,2))
    x34 = x(:,3).^4
    y(:,1) = s1 + a.*s2.^2 + b.*x34.*s1
endfunction
a=7.;
b=0.1;
distfun_seedset(0);
[ s , nbevalf ] = nisp_sobolsaFirst ( list(ishigami2,a,b) , nx , myrandgen );
assert_checkalmostequal ( s, SE , 1.e-1 , 1.e-2 );
assert_checkequal ( nbevalf , 40000 );
//
// With additionnal arguments for randgen.
function x = myrandgen2 ( n , i , xmin , xmax )
    x = distfun_unifrnd(xmin,xmax,n,1)
endfunction
distfun_seedset(0);
[ s , nbevalf ] = nisp_sobolsaFirst ( ishigami , nx , list(myrandgen2,-%pi,%pi) );
assert_checkalmostequal ( s, SE , 1.e-1 , 1.e-2 );
assert_checkequal ( nbevalf , 40000 );

//
// Do not set into [0,1] range 
distfun_seedset(0);
s = nisp_sobolsaFirst ( ishigami , nx , myrandgen, [], %f );
assert_checkalmostequal ( s, SE , 1.e-1 , 1.e-2 );
// This is the check: if inrange is true, s(3) is zero
assert_checktrue ( s(3) < 0 ); 

//
// Set into [0,1] range 
distfun_seedset(0);
s = nisp_sobolsaFirst ( ishigami , nx , myrandgen);
assert_checkalmostequal ( s, SE , 1.e-1 , 1.e-2 );
// This is the check: if inrange is true, s(3) is zero
assert_checkequal ( s(3) , 0 );
 
//
// Get confidence interval
distfun_seedset(0);
[ s , nbevalf, smin, smax ] = nisp_sobolsaFirst ( ishigami , nx , myrandgen, [], [], 1-0.95 );
assert_checkalmostequal ( s, SE , 1.e-1 , 1.e-2 );
assert_checkequal ( nbevalf , 40000 );
assert_checkalmostequal ( smin, [0.2873819  0.4287371  0.]', 1.e-1 , 1.e-2 );
assert_checkalmostequal ( smax, [0.3229305  0.4601909  0.0114629]', 1.e-1 , 1.e-2 );

