// Copyright (C) 2012-2013 - Michael Baudin
// Copyright (C) 2008-2009 - INRIA - Michael Baudin
// Copyright (C) 2010 - INRIA - Michael Baudin
//
// This file must be used under the terms of the GNU Lesser General Public License license :
// http://www.gnu.org/copyleft/lesser.html

// <-- JVM NOT MANDATORY -->

// Test setrandvar_getsample, when there is 
// no DOE > an error is generated
srv = setrandvar_new ( );
rv1 = randvar_new("Normale",1.0,0.5);
rv2 = randvar_new("Uniforme",1.0,2.5);
setrandvar_addrandvar ( srv , rv1 );
setrandvar_addrandvar ( srv , rv2 );
instr = "s = setrandvar_getsample ( srv , 12 , 13 )";
errmsg = "NISP: Error at the library level:";
assert_checkerror ( instr, errmsg );
setrandvar_destroy(srv);
randvar_destroy(rv1);
randvar_destroy(rv2);

// Test setrandvar_setsample with "foo" sampling and 12 simulations
// Set the sample twice to see if and error is generated so that no memory is lost.
srv = setrandvar_new ( );
rv1 = randvar_new("Normale",1.0,0.5);
rv2 = randvar_new("Uniforme",1.0,2.5);
setrandvar_addrandvar ( srv , rv1 );
setrandvar_addrandvar ( srv , rv2 );
np = 12;
setrandvar_setsample ( srv , "MonteCarlo" , np );
// The second call makes NISP generate an error
// setrandvar_setsample ( srv , "foo" , np );
setrandvar_destroy(srv);
randvar_destroy(rv1);
randvar_destroy(rv2);

// Test setrandvar_setsample with "MonteCarlo" sampling and 12 simulations
// test setrandvar_setsample / setrandvar_getsample with a scalar
srv = setrandvar_new ( );
rv1 = randvar_new("Normale",1.0,0.5);
rv2 = randvar_new("Uniforme",1.0,2.5);
setrandvar_addrandvar ( srv , rv1 );
setrandvar_addrandvar ( srv , rv2 );
np = 12;
setrandvar_setsample ( srv , "MonteCarlo" , np );
for k = 1 : np
  for i = 1 : 2
    value = k+i;
    setrandvar_setsample ( srv , k , i , value );
  end
end
for k = 1 : np
  for i = 1 : 2
    computed = setrandvar_getsample ( srv , k , i );
    expected = k+i;
    assert_checkalmostequal ( computed , expected , %eps);
  end
end
setrandvar_destroy(srv);
randvar_destroy(rv1);
randvar_destroy(rv2);

// Test setrandvar_getsample with a matrix / a vector
srv = setrandvar_new ( );
rv1 = randvar_new("Normale",1.0,0.5);
rv2 = randvar_new("Uniforme",1.0,2.5);
setrandvar_addrandvar ( srv , rv1 );
setrandvar_addrandvar ( srv , rv2 );
np = 12;
setrandvar_setsample ( srv , "MonteCarlo" , np );
for k = 1 : np
  for i = 1 : 2
    setrandvar_setsample ( srv , k , i , k+i );
  end
end
for k = 1 : np
  // Get the sample for experiment #k
  computed = setrandvar_getsample ( srv , k );
  expected = k + [1:2];
  assert_checkalmostequal ( computed , expected , %eps);
end
// Get the sampling matrix
computed = setrandvar_getsample ( srv );
expected = [
2 3
3 4
4 5
5 6
6 7
7 8
8 9
9 10
10 11
11 12
12 13
13 14
];
assert_checkalmostequal ( computed , expected , %eps);
setrandvar_destroy(srv);
randvar_destroy(rv1);
randvar_destroy(rv2);

// Test setrandvar_setsample with vector
srv = setrandvar_new ( );
rv1 = randvar_new("Normale",1.0,0.5);
rv2 = randvar_new("Uniforme",1.0,2.5);
setrandvar_addrandvar ( srv , rv1 );
setrandvar_addrandvar ( srv , rv2 );
np = 12;
setrandvar_setsample ( srv , "MonteCarlo" , np );
expected = [123 456];
setrandvar_setsample ( srv , 6 , expected );
computed = setrandvar_getsample ( srv , 6 );
assert_checkalmostequal ( computed , expected , %eps);
setrandvar_destroy(srv);
randvar_destroy(rv1);
randvar_destroy(rv2);

// Test setrandvar_setsample with matrix
srv = setrandvar_new ( );
rv1 = randvar_new("Normale",1.0,0.5);
rv2 = randvar_new("Uniforme",1.0,2.5);
setrandvar_addrandvar ( srv , rv1 );
setrandvar_addrandvar ( srv , rv2 );
np = 12;
setrandvar_setsample ( srv , "MonteCarlo" , np );
expected = [
2 3
3 4
4 5
5 6
6 7
7 8
8 9
9 10
10 11
11 12
12 13
13 14
];
setrandvar_setsample ( srv , expected );
computed = setrandvar_getsample ( srv );
assert_checkalmostequal ( computed , expected , %eps);
setrandvar_destroy(srv);
randvar_destroy(rv1);
randvar_destroy(rv2);

